@@ -13,12 +13,14 @@ import Control.Monad.Trans.Resource (ResourceT, runResourceT)
 import Stackctl.AWS
 import Stackctl.AWS.Scope
 import Stackctl.ColorOption
+import Stackctl.Config
 import Stackctl.DirectoryOption
 import Stackctl.FilterOption
 import Stackctl.VerboseOption
 
 data App options = App
   { appLogger :: Logger
+  , appConfig :: Config
   , appOptions :: options
   , appAwsScope :: AwsScope
   , appAwsEnv :: AwsEnv
@@ -30,6 +32,9 @@ optionsL = lens appOptions $ \x y -> x { appOptions = y }
 instance HasLogger (App options) where
   loggerL = lens appLogger $ \x y -> x { appLogger = y }
 
+instance HasConfig (App options) where
+  configL = lens appConfig $ \x y -> x { appConfig = y }
+
 instance HasAwsScope (App options) where
   awsScopeL = lens appAwsScope $ \x y -> x { appAwsScope = y }
 
@@ -86,14 +91,14 @@ runAppT options f = do
     (options ^. verboseOptionL)
     envLogSettings
 
-  aws <- runLoggerLoggingT logger awsEnvDiscover
+  app <- runResourceT $ runLoggerLoggingT logger $ do
+    aws <- awsEnvDiscover
 
-  let
-    runAws
-      :: MonadUnliftIO m => ReaderT AwsEnv (LoggingT (ResourceT m)) a -> m a
-    runAws = runResourceT . runLoggerLoggingT logger . flip runReaderT aws
-
-  app <- App logger options <$> runAws fetchAwsScope <*> pure aws
+    App logger
+      <$> loadConfigOrExit
+      <*> pure options
+      <*> runReaderT fetchAwsScope aws
+      <*> pure aws
 
   let
     AwsScope {..} = appAwsScope app
