@@ -9,8 +9,9 @@ import Data.List.Extra (dropPrefix)
 import qualified Data.List.NonEmpty as NE
 import Stackctl.AWS
 import Stackctl.AWS.Scope
+import Stackctl.Config (HasConfig)
 import Stackctl.DirectoryOption (HasDirectoryOption(..))
-import Stackctl.FilterOption (HasFilterOption(..), filterFilePaths)
+import Stackctl.FilterOption (HasFilterOption(..), filterStackSpecs)
 import Stackctl.StackSpec
 import Stackctl.StackSpecPath
 import System.FilePath (isPathSeparator)
@@ -22,6 +23,7 @@ discoverSpecs
      , MonadLogger m
      , MonadReader env m
      , HasAwsScope env
+     , HasConfig env
      , HasDirectoryOption env
      , HasFilterOption env
      )
@@ -29,7 +31,7 @@ discoverSpecs
 discoverSpecs = do
   dir <- view directoryOptionL
   scope@AwsScope {..} <- view awsScopeL
-  discovered <- globRelativeTo
+  paths <- globRelativeTo
     dir
     [ compile
     $ "stacks"
@@ -52,24 +54,27 @@ discoverSpecs = do
   filterOption <- view filterOptionL
 
   let
-    matched = filterFilePaths filterOption discovered
     toSpecPath = stackSpecPathFromFilePath scope
-    (errs, specPaths) = partitionEithers $ map toSpecPath matched
+    (errs, specPaths) = partitionEithers $ map toSpecPath paths
 
     context =
       [ "path" .= dir
       , "filters" .= filterOption
-      , "discovered" .= length discovered
-      , "matched" .= length matched
+      , "paths" .= length paths
       , "errors" .= length errs
+      , "specs" .= length specPaths
       ]
 
   withThreadContext context $ do
-    logDebug "Discovered specs"
-    when (null matched) $ logWarn "No specs found"
     checkForDuplicateStackNames specPaths
 
-  sortStackSpecs <$> traverse (readStackSpec dir) specPaths
+    specs <-
+      sortStackSpecs
+      . filterStackSpecs filterOption
+      <$> traverse (readStackSpec dir) specPaths
+
+    when (null specs) $ logWarn "No specs found"
+    specs <$ logDebug ("Discovered specs" :# ["matched" .= length specs])
 
 checkForDuplicateStackNames
   :: (MonadIO m, MonadLogger m) => [StackSpecPath] -> m ()
