@@ -6,9 +6,10 @@ module Stackctl.Spec.Generate
 
 import Stackctl.Prelude
 
+import Stackctl.Action
 import Stackctl.AWS
 import Stackctl.AWS.Scope
-import Stackctl.Action
+import Stackctl.Config (HasConfig)
 import Stackctl.Spec.Discover (buildSpecPath)
 import Stackctl.StackSpec
 import Stackctl.StackSpecPath
@@ -23,6 +24,7 @@ data Generate = Generate
   , gStackPath :: Maybe FilePath
   -- ^ If not given, will use @{stack-name}.yaml@
   , gStackName :: StackName
+  , gDescription :: Maybe StackDescription
   , gDepends :: Maybe [StackName]
   , gActions :: Maybe [Action]
   , gParameters :: Maybe [Parameter]
@@ -40,6 +42,7 @@ generate
      , MonadUnliftIO m
      , MonadLogger m
      , MonadReader env m
+     , HasConfig env
      , HasAwsScope env
      )
   => Generate
@@ -59,15 +62,16 @@ generate Generate {..} = do
   let
     templatePath = fromMaybe defaultTemplatePath gTemplatePath
     specYaml = StackSpecYaml
-      { ssyTemplate = templatePath
+      { ssyDescription = gDescription
+      , ssyTemplate = templatePath
       , ssyDepends = gDepends
       , ssyActions = gActions
-      , ssyParameters = map ParameterYaml <$> gParameters
+      , ssyParameters = parametersYaml . mapMaybe parameterYaml <$> gParameters
       , ssyCapabilities = gCapabilities
-      , ssyTags = map TagYaml <$> gTags
+      , ssyTags = tagsYaml . map TagYaml <$> gTags
       }
 
-    stackSpec = buildStackSpec gOutputDirectory specPath specYaml
+  stackSpec <- buildStackSpec gOutputDirectory specPath specYaml
 
   withThreadContext ["stackName" .= stackSpecStackName stackSpec] $ do
     logInfo "Generating specification"
