@@ -3,9 +3,12 @@ module Stackctl.StackSpec
   , stackSpecSpecPath
   , stackSpecSpecBody
   , stackSpecStackName
+  , stackSpecStackDescription
   , stackSpecActions
   , stackSpecParameters
   , stackSpecCapabilities
+  , stackSpecStackFile
+  , stackSpecTemplateFile
   , stackSpecTags
   , buildStackSpec
   , TemplateBody
@@ -23,11 +26,13 @@ import Data.Aeson
 import qualified Data.ByteString.Lazy as BSL
 import Data.List.Extra (nubOrdOn)
 import qualified Data.Yaml as Yaml
-import Stackctl.AWS
 import Stackctl.Action
+import Stackctl.AWS
+import Stackctl.Config (HasConfig(..), applyConfig)
 import Stackctl.Sort
 import Stackctl.StackSpecPath
 import Stackctl.StackSpecYaml
+import qualified System.FilePath as FilePath
 import System.FilePath (takeExtension)
 import UnliftIO.Directory (createDirectoryIfMissing)
 
@@ -46,28 +51,48 @@ stackSpecSpecBody = ssSpecBody
 stackSpecStackName :: StackSpec -> StackName
 stackSpecStackName = stackSpecPathStackName . ssSpecPath
 
+stackSpecStackDescription :: StackSpec -> Maybe StackDescription
+stackSpecStackDescription = ssyDescription . ssSpecBody
+
 stackSpecDepends :: StackSpec -> [StackName]
 stackSpecDepends = fromMaybe [] . ssyDepends . ssSpecBody
 
 stackSpecActions :: StackSpec -> [Action]
 stackSpecActions = fromMaybe [] . ssyActions . ssSpecBody
 
-stackSpecTemplateFile :: StackSpec -> StackTemplate
+-- | Normalized, relative path to the @[{root}/]stacks/@ file
+stackSpecStackFile :: StackSpec -> FilePath
+stackSpecStackFile StackSpec {..} =
+  FilePath.normalise $ ssSpecRoot </> stackSpecPathFilePath ssSpecPath
+
+-- | Normalized, relative path to the @[{root}/]templates/@ file
+stackSpecTemplateFile :: StackSpec -> FilePath
 stackSpecTemplateFile StackSpec {..} =
-  StackTemplate $ ssSpecRoot </> "templates" </> ssyTemplate ssSpecBody
+  FilePath.normalise $ ssSpecRoot </> "templates" </> ssyTemplate ssSpecBody
 
 stackSpecParameters :: StackSpec -> [Parameter]
 stackSpecParameters =
-  maybe [] (map unParameterYaml) . ssyParameters . ssSpecBody
+  maybe [] (map unParameterYaml . unParametersYaml) . ssyParameters . ssSpecBody
 
 stackSpecCapabilities :: StackSpec -> [Capability]
 stackSpecCapabilities = fromMaybe [] . ssyCapabilities . ssSpecBody
 
 stackSpecTags :: StackSpec -> [Tag]
-stackSpecTags = maybe [] (map unTagYaml) . ssyTags . ssSpecBody
+stackSpecTags = maybe [] (map unTagYaml . unTagsYaml) . ssyTags . ssSpecBody
 
-buildStackSpec :: FilePath -> StackSpecPath -> StackSpecYaml -> StackSpec
-buildStackSpec = StackSpec
+buildStackSpec
+  :: (MonadReader env m, HasConfig env)
+  => FilePath
+  -> StackSpecPath
+  -> StackSpecYaml
+  -> m StackSpec
+buildStackSpec dir specPath specBody = do
+  config <- view configL
+  pure StackSpec
+    { ssSpecRoot = dir
+    , ssSpecPath = specPath
+    , ssSpecBody = applyConfig config specBody
+    }
 
 data TemplateBody
   = TemplateText Text
@@ -113,18 +138,17 @@ writeStackSpec parent stackSpec@StackSpec {..} templateBody = do
   createDirectoryIfMissing True $ takeDirectory specPath
   liftIO $ Yaml.encodeFile specPath ssSpecBody
  where
-  templatePath = unStackTemplate $ stackSpecTemplateFile stackSpec
+  templatePath = stackSpecTemplateFile stackSpec
   specPath = parent </> stackSpecPathFilePath ssSpecPath
 
-readStackSpec :: MonadIO m => FilePath -> StackSpecPath -> m StackSpec
+readStackSpec
+  :: (MonadIO m, MonadReader env m, HasConfig env)
+  => FilePath
+  -> StackSpecPath
+  -> m StackSpec
 readStackSpec dir specPath = do
   specBody <- liftIO $ either err pure =<< Yaml.decodeFileEither path
-
-  pure StackSpec
-    { ssSpecRoot = dir
-    , ssSpecPath = specPath
-    , ssSpecBody = specBody
-    }
+  buildStackSpec dir specPath specBody
  where
   path = dir </> stackSpecPathFilePath specPath
   err e =
@@ -143,7 +167,8 @@ createChangeSet
   -> m (Either Text (Maybe ChangeSet))
 createChangeSet spec parameters = awsCloudFormationCreateChangeSet
   (stackSpecStackName spec)
-  (stackSpecTemplateFile spec)
+  (stackSpecStackDescription spec)
+  (StackTemplate $ stackSpecTemplateFile spec)
   (nubOrdOn (^. parameter_parameterKey) $ parameters <> stackSpecParameters spec
   )
   (stackSpecCapabilities spec)
